"use client"

import { motion } from "framer-motion"
import { Card, CardContent } from "@/components/ui/card"
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar"
import { Star } from "lucide-react"

export default function Testimonials() {
  const testimonials = [
    {
      name: "Ahmet Yılmaz",
      role: "Restoran Sahibi",
      content:
        "Anamur AI'nin AI garson sistemi sayesinde sipariş hatalarımız %80 azaldı ve müşteri memnuniyetimiz arttı. Teknolojileri gerçekten işimizi dönüştürdü.",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 5,
    },
    {
      name: "Ayşe Kaya",
      role: "Pazarlama Direktörü",
      content:
        "Yapay zeka destekli içerik üretimi ve SEO stratejileri ile web sitemizin trafiğini 3 ayda %150 artırdık. Anamur AI ekibi her adımda yanımızdaydı.",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 5,
    },
    {
      name: "Mehmet Demir",
      role: "Klinik Yöneticisi",
      content:
        "AI terapist asistanımız, hastaların ilk değerlendirmelerini yaparak doktorlarımızın zamanını önemli ölçüde serbest bıraktı. Hasta memnuniyeti de arttı.",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 4,
    },
  ]

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2,
      },
    },
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 },
    },
  }

  return (
    <section className="py-20 relative" id="testimonials">
      <div className="container relative z-10">
        <div className="text-center mb-16">
          <h2 className="text-4xl font-bold mb-4 golden-text">Müşteri Yorumları</h2>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            Müşterilerimizin Anamur AI çözümleri hakkında ne söylediklerini keşfedin.
          </p>
        </div>

        <motion.div
          className="grid md:grid-cols-3 gap-8"
          variants={containerVariants}
          initial="hidden"
          whileInView="visible"
          viewport={{ once: true, amount: 0.2 }}
        >
          {testimonials.map((testimonial, index) => (
            <motion.div key={index} variants={itemVariants}>
              <Card className="h-full glass-card hover:neon-border transition-all duration-300">
                <CardContent className="pt-6">
                  <div className="flex mb-4">
                    {[...Array(5)].map((_, i) => (
                      <Star
                        key={i}
                        className={`h-4 w-4 ${i < testimonial.rating ? "text-yellow-500 fill-yellow-500" : "text-gray-600"}`}
                      />
                    ))}
                  </div>
                  <p className="mb-6 text-gray-300">"{testimonial.content}"</p>
                  <div className="flex items-center">
                    <Avatar className="h-10 w-10 mr-3 border border-primary/30">
                      <AvatarImage src={testimonial.avatar} alt={testimonial.name} />
                      <AvatarFallback className="bg-primary/20 text-primary">
                        {testimonial.name.charAt(0)}
                      </AvatarFallback>
                    </Avatar>
                    <div>
                      <p className="font-medium text-white">{testimonial.name}</p>
                      <p className="text-sm text-muted-foreground">{testimonial.role}</p>
                    </div>
                  </div>
                </CardContent>
              </Card>
            </motion.div>
          ))}
        </motion.div>
      </div>
    </section>
  )
}

